@@ -5,9 +5,11 @@ use warnings;
 use Carp;
 use Cwd 'realpath';
 
-our $VERSION   = '1.3095_02';
+our $VERSION   = '1.3111_01';
 our $AUTHORITY = 'SUKRIA';
 
+$VERSION = eval $VERSION;
+
 use Dancer::App;
 use Dancer::Config;
 use Dancer::Cookies;
@@ -36,6 +38,7 @@ use Dancer::Continuation::Route::FileSent;
 use Dancer::Continuation::Route::Templated;
 
 use File::Spec;
+use Scalar::Util;
 
 use base 'Exporter';
 
@@ -225,6 +228,7 @@ sub import {
     my ($package, $script) = caller;
 
     strict->import;
+    warnings->import;
     utf8->import;
 
     my @final_args;
@@ -380,6 +384,11 @@ sub _send_file {
         $request->content_type($options{content_type});
     }
 
+    # If we're given an IO::Scalar object, DTRT (take the scalar ref from it)
+    if (Scalar::Util::blessed($path) && $path->isa('IO::Scalar')) {
+        $path = $path->sref;
+    }
+
     my $resp;
     if (ref($path) eq "SCALAR") {
         # send_data
@@ -459,6 +468,10 @@ sub _start {
 
     # Backward compatibility for app.psgi that has sub { Dancer->dance($req) }
     if ($request) {
+        Dancer::Handler->init_request_headers( $request->env );
+        # TODO _build_headers should either not be private, or we should call
+        # init
+        $request->_build_headers;
         return Dancer::Handler->handle_request($request);
     }
 
@@ -834,7 +847,7 @@ Sets a response object with the content given.
 When used as a return value from a filter, this breaks the execution flow and
 renders the response immediately:
 
-    before sub {
+    hook before sub {
         if ($some_condition) {
             halt("Unauthorized");
             # This code is not executed :
@@ -935,8 +948,8 @@ This hook receives as argument a L<Dancer::Error> object.
 
 =item before
 
-This hook receives one argument, a reference to the subroutine that
-implements the route that is being intercepted by this hook.
+This hook receives one argument, the route being executed (a L<Dancer::Route>
+object).
 
   hook before => sub {
     my $route_handler = shift;
@@ -1044,7 +1057,7 @@ if it needs to make changes to the response which is about to be sent.
     my $response = shift;
   };
 
-This is equivalent to
+This is equivalent to the deprecated
 
   after sub {
     my $response = shift;
@@ -1434,7 +1447,7 @@ it:
             streaming => 1,
             callbacks => {
                 around => sub {
-                    my ( $writer, $content 0 = shift;
+                    my ( $writer, $content ) = @_;
 
                     # we know it's a text file, so we'll just stream
                     # line by line
@@ -1819,7 +1832,7 @@ versions:
 Provides an accessor for variables shared between filters and route handlers.
 Given a key/value pair, it sets a variable:
 
-    before sub {
+    hook before sub {
         var foo => 42;
     };
 
@@ -1857,11 +1870,12 @@ see the AUTHORS file that comes with this distribution for details.
 =head1 SOURCE CODE
 
 The source code for this module is hosted on GitHub
-L<http://github.com/sukria/Dancer>.  Feel free to fork the repository and submit
-pull requests!  (See L<Dancer::Development> for details on how to contribute).
+L<https://github.com/PerlDancer/Dancer>.  Feel free to fork the repository and
+submit pull requests!  (See L<Dancer::Development> for details on how to
+contribute).
 
-Also, why not L<watch the repo|https://github.com/sukria/Dancer/toggle_watch> to
-keep up to date with the latest upcoming changes?
+Also, why not L<watch the repo|https://github.com/PerlDancer/Dancer/toggle_watch>
+to keep up to date with the latest upcoming changes?
 
 
 =head1 GETTING HELP / CONTRIBUTING
@@ -1874,7 +1888,7 @@ client at L<http://www.perldancer.org/irc> for you.
 
 There is also a Dancer users mailing list available - subscribe at:
 
-L<http://lists.perldancer.org/cgi-bin/listinfo/dancer-users>
+L<http://lists.preshweb.co.uk/mailman/listinfo/dancer-users>
 
 If you'd like to contribute to the Dancer project, please see
 L<http://www.perldancer.org/contribute> for all the ways you can help!
