@@ -3,6 +3,7 @@ package Dancer::Session;
 use strict;
 use warnings;
 
+use Carp;
 use Dancer::Cookies;
 use Dancer::Engine;
 
@@ -28,8 +29,12 @@ sub get_current_session {
 
     if (not defined $session) {
         $session = $class->create();
-        engine->write_session_id($session->id);
     }
+
+    # Generate a session cookie; we want to do this regardless of whether the
+    # session is new or existing, so that the cookie expiry is updated.
+    engine->write_session_id($session->id);
+
     return $session;
 }
 
@@ -44,7 +49,10 @@ sub read {
 
 sub write {
     my ($class, $key, $value) = @_;
+
     return unless $key;
+    $key eq 'id' and croak 'Can\'t store to session key with name "id"';
+
     my $session = get_current_session();
     $session->{$key} = $value;
 
@@ -120,7 +128,7 @@ and C</home> actions using the session engine.
         # /login
         if (not session('user_id')) {
             redirect '/login';
-        a
+        }
     };
 
 Of course, you probably don't want to have to duplicate the code to check
